==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fInvokestatic.h <==
// class soot.coffi.Instruction_Invokestatic

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 4c02649c14e871c1 soot_coffi_Instruction__5fInvokestatic
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fInvokestatic_H_
#define _JC_soot_coffi_Instruction__5fInvokestatic_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fInvokestatic$sub_refs	_jc_soot_coffi_Instruction__5fInvokestatic$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fInvokestatic$sub_nonrefs	_jc_soot_coffi_Instruction__5fInvokestatic$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fInvokestatic$refs	_jc_soot_coffi_Instruction__5fInvokestatic$refs;
typedef struct _jc_soot_coffi_Instruction__5fInvokestatic$nonrefs	_jc_soot_coffi_Instruction__5fInvokestatic$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fInvokestatic$object	_jc_soot_coffi_Instruction__5fInvokestatic$object;

typedef const struct _jc_soot_coffi_Instruction__5fInvokestatic$vmethods	_jc_soot_coffi_Instruction__5fInvokestatic$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fInvokestatic$vtable	_jc_soot_coffi_Instruction__5fInvokestatic$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fInvokestatic$vtype	_jc_soot_coffi_Instruction__5fInvokestatic$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fInvokestatic$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fInvokestatic$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fInvokestatic$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fInvokestatic$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fInvokestatic$vmethods	soot_coffi_Instruction__5fInvokestatic;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fInvokestatic$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fInvokestatic$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fInvokestatic$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fInvokestatic$refs {
    _jc_soot_coffi_Instruction__5fInvokestatic$sub_refs	soot_coffi_Instruction__5fInvokestatic;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fInvokestatic$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fInvokestatic$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fInvokestatic$sub_nonrefs	soot_coffi_Instruction__5fInvokestatic;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fInvokestatic$object {
	_jc_soot_coffi_Instruction__5fInvokestatic$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fInvokestatic$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fInvokestatic$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fInvokestatic$vtype _jc_soot_coffi_Instruction__5fInvokestatic$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fInvokestatic, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fInvokestatic$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fInvokestatic_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fInvokestatic.h <==
// class soot.coffi.Instruction_Invokestatic

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 4c02649c14e871c1 soot_coffi_Instruction__5fInvokestatic
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fInvokestatic_H_
#define _JC_soot_coffi_Instruction__5fInvokestatic_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fInvokestatic$sub_refs	_jc_soot_coffi_Instruction__5fInvokestatic$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fInvokestatic$sub_nonrefs	_jc_soot_coffi_Instruction__5fInvokestatic$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fInvokestatic$refs	_jc_soot_coffi_Instruction__5fInvokestatic$refs;
typedef struct _jc_soot_coffi_Instruction__5fInvokestatic$nonrefs	_jc_soot_coffi_Instruction__5fInvokestatic$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fInvokestatic$object	_jc_soot_coffi_Instruction__5fInvokestatic$object;

typedef const struct _jc_soot_coffi_Instruction__5fInvokestatic$vmethods	_jc_soot_coffi_Instruction__5fInvokestatic$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fInvokestatic$vtable	_jc_soot_coffi_Instruction__5fInvokestatic$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fInvokestatic$vtype	_jc_soot_coffi_Instruction__5fInvokestatic$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fInvokestatic$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fInvokestatic$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fInvokestatic$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fInvokestatic$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fInvokestatic$vmethods	soot_coffi_Instruction__5fInvokestatic;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fInvokestatic$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fInvokestatic$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fInvokestatic$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fInvokestatic$refs {
    _jc_soot_coffi_Instruction__5fInvokestatic$sub_refs	soot_coffi_Instruction__5fInvokestatic;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fInvokestatic$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fInvokestatic$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fInvokestatic$sub_nonrefs	soot_coffi_Instruction__5fInvokestatic;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fInvokestatic$object {
	_jc_soot_coffi_Instruction__5fInvokestatic$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fInvokestatic$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fInvokestatic$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fInvokestatic$vtype _jc_soot_coffi_Instruction__5fInvokestatic$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fInvokestatic, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fInvokestatic$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fInvokestatic_H_ */
